@@ -9,7 +9,7 @@
 #
 package Pod::Weaver::Section::RSRCHBOY::Authors;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Pod::Weaver::Section::RSRCHBOY::Authors::VERSION = '0.066';
+$Pod::Weaver::Section::RSRCHBOY::Authors::VERSION = '0.067';
 # ABSTRACT: An AUTHORS section with materialistic pleasures
 
 use v5.10;
@@ -26,9 +26,25 @@ use URI::Escape::XS 'uri_escape';
 
 extends 'Pod::Weaver::Section::Authors';
 
+
+has feed_me => (is => 'rw', isa => 'Bool', lazy => 1, builder => sub { 1 });
+
+before weave_section => sub {
+    my ($self, $output, $input) = @_;
+
+    # skip this unless we're under dzil *and* have the right stash
+    return unless $input && $input->{zilla};
+    my $stash = $input->{zilla}->stash_named('%PodWeaver') // return;
+
+    $stash->merge_stashed_config($self);
+    return;
+};
+
 after weave_section => sub {
     my ($self, $output, $input) = @_;
 
+    return unless $self->feed_me;
+
     my $name = $input->{distmeta}->{name};
 
     my $flattr_img   = 'http://api.flattr.com/button/flattr-badge-large.png';
@@ -104,7 +120,7 @@ Pod::Weaver::Section::RSRCHBOY::Authors - An AUTHORS section with materialistic
 
 =head1 VERSION
 
-This document describes version 0.066 of Pod::Weaver::Section::RSRCHBOY::Authors - released August 07, 2015 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.067 of Pod::Weaver::Section::RSRCHBOY::Authors - released May 05, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 DESCRIPTION
 
@@ -114,6 +130,12 @@ desires.
 
 What the frak; let's see what happens.
 
+=head1 ATTRIBUTES
+
+=head2 feed_me
+
+Boolean.  Set to false to disable our pledge-drive section :)
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
